Learn R Programming

govStatJPN (version 0.1)

get.meta.info: Object to Get Meta Data of a Specified Survey.

Description

This function purposes to get a meta data API offers.

Usage

get.meta.info(app.id, stat.id)

Arguments

app.id
Your application ID. Using all functions contained govStatJPN package, this ID is required. Registration page is https://statdb.nstac.go.jp/apiuser/php/index.php?action=provisional Login page is https://statdb.nstac.go.jp/apiuser/php/index.php?action=login After logging in, you are able to issue your application ID.
stat.id
Required. This is an id in retuned values of get.stat.list.

Value

A data frame object is returned.

Details

This function is based on section 3.3 at the published pdf file (http://statdb.nstac.go.jp/wp/wp-content/uploads/2013/06/API-spec.pdf).

References

http://statdb.nstac.go.jp/ http://statdb.nstac.go.jp/wp/wp-content/uploads/2013/06/API-spec.pdf

See Also

get.stat.list, get.stat.data

Examples

Run this code
	# app.id <- 'your application ID'
	# stat.list <- get.stat.list(app.id, list(surveyYears=2007, lang='J'))
	# meta.info <- get.meta.info(app.id, stat.list$id[1])
	# meta.info

Run the code above in your browser using DataLab