Learn R Programming

govStatJPN (version 0.1)

govStatJPN-package: Package to load public survey data by Japanese government offered via their Application Programming Interface (API).

Description

This package purposes to use the public data in simple way. This product uses the Gateway to Advanced and User-friendly Statistics Service API but is not endorsed or certified by the Statistics Bureau or the National Statistics Center.

Arguments

Details

Package:
govStatJPN
Type:
Package
Version:
0.1a
Date:
2013-06-11
License:
Yuichiro Otani
LazyLoad:
yes

References

http://statdb.nstac.go.jp/ http://statdb.nstac.go.jp/wp/wp-content/uploads/2013/06/API-spec.pdf

See Also

get.stat.list, get.meta.info, get.stat.data

Examples

Run this code
	# library(govStatJPN)

Run the code above in your browser using DataLab