govStatJPN-package:
Package to load public survey data by Japanese government offered via their Application Programming Interface (API).
Description
This package purposes to use the public data in simple way.
This product uses the Gateway to Advanced and User-friendly Statistics Service API but is not endorsed or certified by the Statistics Bureau or the National Statistics Center.